# mrsr

![GitHub](https://img.shields.io/github/license/omadson/mrsr.svg)
[![PyPI](https://img.shields.io/pypi/v/mrsr.svg)](http://pypi.org/project/mrsr/)
[![GitHub commit activity](https://img.shields.io/github/commit-activity/w/omadson/mrsr.svg)](https://github.com/omadson/mrsr/pulse)
[![GitHub last commit](https://img.shields.io/github/last-commit/omadson/mrsr.svg)](https://github.com/omadson/mrsr/commit/master)
[![Downloads](https://pepy.tech/badge/mrsr)](https://pepy.tech/project/mrsr)


`mrsr` is a Python module implementing the [Multiresponse Sparse Regression algorithm][1] clustering algorithm.

## instalation
the `mrsr` package is available in [PyPI](https://pypi.org/project/mrsr/). to install, simply type the following command:
```
pip install mrsr
```

## how to cite mrsr package
if you use `mrsr` package in your paper, please cite it in your publication.
```
@misc{mrsr,
    author       = "Madson Luiz Dantas Dias",
    year         = "2019",
    title        = "mrsr: a Python module implementing the Multiresponse Sparse Regression algorithm.",
    url          = "https://github.com/omadson/mrsr",
    institution  = "Federal University of Cear\'{a}, Department of Computer Science" 
}
```

## contributing

this project is open for contributions. here are some of the ways for you to contribute:
 - bug reports/fix
 - features requests
 - use-case demonstrations

to make a contribution, just fork this repository, push the changes in your fork, open up an issue, and make a pull request!

## contributors
 - [Madson Dias](https://github.com/omadson)

[1]: https://doi.org/10.1109/IJCNN.2006.246933
[2]: http://scikit-learn.org/
